@@ -46,7 +46,7 @@ DEFAULT_SPECD_PATH = os.path.join(
     os.path.dirname(__file__), "../../gosdk/specs/"
 )
 
-VERSION = "0.9.18"
+VERSION = "0.9.19"
 COPYRIGHT = "Copyright: GenomOncology, LLC"
 
 
@@ -236,6 +236,16 @@ def aggregate_cosmic(state, cosmic_tsv_path):
     return [sources.AggregatedCOSMICSources(cosmic_tsv=cosmic_tsv_path)]
 
 
+@gocli.command()
+@click.argument(
+    "record_type",
+    type=click.Choice(['cnv', 'fusion']),
+)
+@options.build_option
+@options.pass_state
+def aggregate_non_snv_cosmic(state, record_type):
+    return [sources.AggregatedCOSMICNonSNVSources(record_type=record_type)]
+
 @gocli.command()
 @click.option(
     "--column",
@@ -418,7 +428,8 @@ def annotate_calls(
 @options.size_option
 @options.build_option
 @options.pass_state
-def annotate_match(state, run_async, delete_if_exists, keep_ref_unknown_calls):
+@options.timeout_option
+def annotate_match(state, timeout, run_async, delete_if_exists, keep_ref_unknown_calls):
     """Get annotations for stream of calls."""
     if run_async:
         create_function = kms.create_async_processor
@@ -428,7 +439,7 @@ def annotate_match(state, run_async, delete_if_exists, keep_ref_unknown_calls):
         sdk_function = kms.annotations.sync_annotate_match
 
     # get the annotation bundle version once instead of once per batch
-    sdk = state.create_sdk(async_enabled=False)
+    sdk = state.create_sdk(async_enabled=False, timeout=state.timeout)
     annotation_bundle_version = kms.annotations.get_annotation_bundle_version(
         sdk
     )
@@ -454,6 +465,56 @@ def annotate_match(state, run_async, delete_if_exists, keep_ref_unknown_calls):
     ]
 
 
+@gocli.command()
+@click.option(
+    "--async",
+    "-a",
+    "run_async",
+    help="Run in asynchronous mode.",
+    is_flag=True,
+)
+@click.option(
+    "--delete-if-exists",
+    "-d",
+    "delete_if_exists",
+    help="Delete if annotations exist.",
+    is_flag=True,
+)
+@options.size_option
+@options.build_option
+@options.timeout_option
+@options.pass_state
+def annotate_match_bed(state, timeout, run_async, delete_if_exists):
+
+    """this function hits the annotations/match endpoint. It
+        allows the user to send genes
+        to the endpoint for annotation."""
+
+    """Get annotations for stream of calls.
+    the sdk_function is what makes the call to the
+     api endpoint and returns the data"""
+    if run_async:
+        create_function = kms.create_async_processor
+        sdk_function = kms.annotations.async_annotate_genes
+    else:
+        create_function = kms.create_sync_processor
+        sdk_function = kms.annotations.sync_annotate_genes
+
+    return [
+        filter(is_header),
+        partition_all(
+            state.batch_size
+        ),  # annotate calls is GET, hardcoded batch size
+        create_function(
+            state,
+            sdk_function,
+            delete_if_exists=delete_if_exists,
+            build=state.build,
+        ),
+        concat,
+    ]
+
+
 @gocli.command()
 @options.build_option
 @options.pass_state
@@ -979,17 +1040,29 @@ def refresh_annotations(state, recalculate_hgvs, bed):
 
 
 @gocli.command()
+@click.option("--genes", type=bool, default=False)
 @options.pass_state
-def region_search(state):
-    """Searches for Transcript in region specified by bed file"""
+def region_search(state, genes):
+    """Searches for Transcript in region specified
+    by bed file"""
+    """if genes is True then we will
+            return the names of the genes
+          that are processed in the bed file. These
+          can then be used for further processing
+          for instance using the annotate_match_bed command
+           which will annotate them."""
+
+    process_func = (
+        kms.transcripts.process_transcript_batch_get_genes
+        if genes
+        else kms.transcripts.process_transcript_batch
+    )
+
     return [
         filter(DocType.HEADER.is_not),
         partition_all(state.batch_size),
-        kms.create_sync_processor(
-            state, kms.transcripts.process_transcript_batch
-        ),
+        kms.create_sync_processor(state, process_func),
         concat,
-        sinks.JsonlFileSink,
     ]
 
 
