@@ -35,6 +35,48 @@ def hotspot_annotate(data, data_set, data_set_version, sdk=None):
 EXCLUDE_BUILD_FIELDS = ["is_gene_annotation"]
 
 
+@curry
+def sync_annotate_genes(
+    batch_of_genes_to_be_annotated,
+    sdk=None,
+    delete_if_exists=False,
+    build=GRCh37,
+):
+
+    # genes_annotation_list will make the call and will hold the results
+    # of the call which will be annotated genes in an object
+    # AnnotationMatchList
+    genes_annotations_list = sdk.call_with_retry(
+        sdk.annotations.post_annotations_match,
+        batch=batch_of_genes_to_be_annotated,
+        delete_if_exists=delete_if_exists,
+        build=build,
+    )
+    # generator converts the objects returned into a dict format
+    for gene in batch_of_genes_to_be_annotated:
+        yield obj_to_dict(
+            None, genes_annotations_list.get_annotation(gene)
+        ) or {}  # noqa
+
+
+@curry
+async def async_annotate_genes(
+    data, sdk=None, delete_if_exists=False, build=GRCh37
+):
+    batch_of_genes = data
+    genes_annotations_list = sdk.call_with_retry(
+        sdk.annotations.post_annotations_match,
+        batch=batch_of_genes,
+        delete_if_exists=delete_if_exists,
+        build=build,
+    )
+    # generator converts the objects returned into a dict format
+    for gene in data:
+        yield obj_to_dict(
+            None, genes_annotations_list.get_annotation(gene)
+        ) or {}  # noqa
+
+
 @curry
 async def async_annotate_match(
     data,
@@ -545,10 +587,16 @@ def parse_bnd_sv_hashes(record, data):
 
             rel_orien = ""
             same = "(?:% s)" % "|".join(
-                ["](chr)?([0-9]+|[xyXY]):[0-9]+]\w", "\w\[(chr)?([0-9]+|[xyXY]):[0-9]+\["]
+                [
+                    "](chr)?([0-9]+|[xyXY]):[0-9]+]\w",
+                    "\w\[(chr)?([0-9]+|[xyXY]):[0-9]+\[",
+                ]
             )
             reverse = "(?:% s)" % "|".join(
-                ["\[(chr)?([0-9]+|[xyXY]):[0-9]+\[\w", "\w](chr)?([0-9]+|[xyXY]):[0-9]+]"]
+                [
+                    "\[(chr)?([0-9]+|[xyXY]):[0-9]+\[\w",
+                    "\w](chr)?([0-9]+|[xyXY]):[0-9]+]",
+                ]
             )
 
             if re.match(same, record["alt"]):
