@@ -9,8 +9,7 @@ from genomoncology.kms.annotations import AnnBundleVersionAssertionError
 def create_async_processor(
     state: "State", async_func, futures_batch_size=25, **kw
 ):
-    sdk = state.create_sdk(async_enabled=True)
-
+    sdk = state.create_sdk(async_enabled=True, timeout=state.timeout)
     return [
         map(async_func(sdk=sdk, **kw)),
         # roll up the futures in batches, await, flatten
@@ -21,7 +20,7 @@ def create_async_processor(
 
 
 def create_sync_processor(state: "State", sync_func, **kw):
-    sdk = state.create_sdk(async_enabled=False)
+    sdk = state.create_sdk(async_enabled=False, timeout=state.timeout)
     return map(sync_func(sdk=sdk, **kw))
 
 
