@@ -2,7 +2,7 @@ from .base import Sink, JsonlFileSink, TextFileSink
 from .tsv import TsvFileSink
 from .excel import ExcelSink
 from .alterations import TempAlterationSink
-from .vcf import VcfFileSink, DummyVariantRecord
+from .vcf import VcfFileSink, DummyVariantRecord, HistoricalVcfFileSink
 from .annotations import LoadAnnotationSink
 from .warehouse import LoadWarehouseVariantsSink, LoadWarehouseFeaturesSink
 
@@ -19,4 +19,5 @@ __all__ = (
     "LoadAnnotationSink",
     "LoadWarehouseVariantsSink",
     "LoadWarehouseFeaturesSink",
+    "HistoricalVcfFileSink",
 )
