@@ -16,6 +16,12 @@ NAME_MAPPING = {
     "variant_haplogroup_counts__mint": "variant_haplogroup_counts",
     "haplogroup_counts__mint": "haplogroup_counts",
     "mitoTIP__float": "mitoTIP",
+    "helix_count__int": "helix_count",
+    "helix_total_count__int": "helix_total_count",
+    "helix_frequency__float": "helix_frequency",
+    "gene__string": "gene",
+    "apogee__mstring": "apogee",
+    "csra": "csra",
 }
 
 register(
